@@ -31,6 +31,18 @@ typedef enum
   EPHY_PREFS_UI_TABS_BAR_POSITION_RIGHT
 } EphyPrefsUITabsBarPosition;
 
+typedef enum
+{
+  EPHY_PREFS_READER_FONT_STYLE_SANS,
+  EPHY_PREFS_READER_FONT_STYLE_SERIF,
+} EphyPrefsReaderFontStyle;
+
+typedef enum
+{
+  EPHY_PREFS_READER_COLORS_LIGHT,
+  EPHY_PREFS_READER_COLORS_DARK,
+} EphyPrefsReaderColorScheme;
+
 typedef enum
 {
   EPHY_PREFS_RESTORE_SESSION_POLICY_ALWAYS,
@@ -63,6 +75,10 @@ typedef enum
 #define EPHY_PREFS_UI_TABS_BAR_POSITION          "tabs-bar-position"
 #define EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY "tabs-bar-visibility-policy"
 
+#define EPHY_PREFS_READER_SCHEMA                 "org.gnome.Epiphany.reader"
+#define EPHY_PREFS_READER_FONT_STYLE             "font-style"
+#define EPHY_PREFS_READER_COLOR_SCHEME           "color-scheme"
+
 #define EPHY_PREFS_STATE_SCHEMA                 "org.gnome.Epiphany.state"
 #define EPHY_PREFS_STATE_DOWNLOAD_DIR           "download-dir"
 #define EPHY_PREFS_STATE_RECENT_ENCODINGS       "recent-encodings"
