@@ -685,7 +685,7 @@ synchronizable_manager_set_is_initial_sync (EphySynchronizableManager *manager,
   ephy_sync_utils_set_bookmarks_sync_is_initial (is_initial);
 }
 
-static double
+static gint64
 synchronizable_manager_get_sync_time (EphySynchronizableManager *manager)
 {
   return ephy_sync_utils_get_bookmarks_sync_time ();
@@ -693,7 +693,7 @@ synchronizable_manager_get_sync_time (EphySynchronizableManager *manager)
 
 static void
 synchronizable_manager_set_sync_time (EphySynchronizableManager *manager,
-                                      double                     sync_time)
+                                      gint64                     sync_time)
 {
   ephy_sync_utils_set_bookmarks_sync_time (sync_time);
 }
@@ -739,7 +739,7 @@ ephy_bookmarks_manager_handle_initial_merge (EphyBookmarksManager *self,
   GSequence *bookmarks;
   GSequenceIter *iter;
   GHashTable *dont_upload;
-  double timestamp;
+  gint64 timestamp;
 
   g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
 
@@ -830,7 +830,7 @@ ephy_bookmarks_manager_handle_regular_merge (EphyBookmarksManager *self,
 {
   GPtrArray *to_upload;
   EphyBookmark *bookmark;
-  double timestamp;
+  gint64 timestamp;
 
   g_assert (EPHY_IS_BOOKMARKS_MANAGER (self));
 
